# danielutils v=0.7.8
A utils library for things that I find useful for my coding workflow.\
Feel free to use and / or contribute / improve my code :)

THIS PACKAGE IS IN DEVELOPMENT AND SUBJECT TO CHANGE, USE AT YOUR OWN RISK!